@@ -1,16 +1,25 @@
-"Main interface for codebuild service Client"
-from __future__ import annotations
+"""
+Main interface for codebuild service client
 
+Usage::
+
+    import boto3
+    from mypy_boto3.codebuild import CodeBuildClient
+
+    session = boto3.Session()
+
+    client: CodeBuildClient = boto3.client("codebuild")
+    session_client: CodeBuildClient = session.client("codebuild")
+"""
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, overload
-from botocore.client import BaseClient
+from typing import Any, Dict, List, TYPE_CHECKING, overload
 from botocore.exceptions import ClientError as Boto3ClientError
-
-# pylint: disable=import-self
-import mypy_boto3_codebuild.client as client_scope
-
-# pylint: disable=import-self
-import mypy_boto3_codebuild.paginator as paginator_scope
+from mypy_boto3_codebuild.paginator import (
+    ListBuildsForProjectPaginator,
+    ListBuildsPaginator,
+    ListProjectsPaginator,
+)
 from mypy_boto3_codebuild.type_defs import (
     BatchDeleteBuildsOutputTypeDef,
     BatchGetBuildsOutputTypeDef,
@@ -40,6 +49,7 @@ from mypy_boto3_codebuild.type_defs import (
     ProjectArtifactsTypeDef,
     ProjectCacheTypeDef,
     ProjectEnvironmentTypeDef,
+    ProjectFileSystemLocationTypeDef,
     ProjectSourceTypeDef,
     ProjectSourceVersionTypeDef,
     PutResourcePolicyOutputTypeDef,
@@ -67,52 +77,54 @@ else:
 __all__ = ("CodeBuildClient",)
 
 
-class CodeBuildClient(BaseClient):
+class Exceptions:
+    AccountLimitExceededException: Boto3ClientError
+    ClientError: Boto3ClientError
+    InvalidInputException: Boto3ClientError
+    OAuthProviderException: Boto3ClientError
+    ResourceAlreadyExistsException: Boto3ClientError
+    ResourceNotFoundException: Boto3ClientError
+
+
+class CodeBuildClient:
     """
-    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client)
+    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client)
     """
 
-    exceptions: client_scope.Exceptions
+    exceptions: Exceptions
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def batch_delete_builds(self, ids: List[str]) -> BatchDeleteBuildsOutputTypeDef:
         """
-        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
+        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def batch_get_builds(self, ids: List[str]) -> BatchGetBuildsOutputTypeDef:
         """
-        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
+        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def batch_get_projects(self, names: List[str]) -> BatchGetProjectsOutputTypeDef:
         """
-        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
+        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def batch_get_report_groups(
         self, reportGroupArns: List[str]
     ) -> BatchGetReportGroupsOutputTypeDef:
         """
-        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
+        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def batch_get_reports(self, reportArns: List[str]) -> BatchGetReportsOutputTypeDef:
         """
-        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
+        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def create_project(
         self,
         name: str,
@@ -133,20 +145,19 @@ class CodeBuildClient(BaseClient):
         vpcConfig: VpcConfigTypeDef = None,
         badgeEnabled: bool = None,
         logsConfig: LogsConfigTypeDef = None,
+        fileSystemLocations: List[ProjectFileSystemLocationTypeDef] = None,
     ) -> CreateProjectOutputTypeDef:
         """
-        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.create_project)
+        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.create_project)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def create_report_group(
         self, name: str, type: Literal["TEST"], exportConfig: ReportExportConfigTypeDef
     ) -> CreateReportGroupOutputTypeDef:
         """
-        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
+        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def create_webhook(
         self,
         projectName: str,
@@ -154,46 +165,39 @@ class CodeBuildClient(BaseClient):
         filterGroups: List[List[WebhookFilterTypeDef]] = None,
     ) -> CreateWebhookOutputTypeDef:
         """
-        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
+        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_project(self, name: str) -> Dict[str, Any]:
         """
-        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.delete_project)
+        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.delete_project)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_report(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.delete_report)
+        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.delete_report)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_report_group(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
+        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_resource_policy(self, resourceArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_source_credentials(self, arn: str) -> DeleteSourceCredentialsOutputTypeDef:
         """
-        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
+        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_webhook(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
+        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def describe_test_cases(
         self,
         reportArn: str,
@@ -202,28 +206,25 @@ class CodeBuildClient(BaseClient):
         filter: TestCaseFilterTypeDef = None,
     ) -> DescribeTestCasesOutputTypeDef:
         """
-        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
+        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def generate_presigned_url(
         self,
         ClientMethod: str,
         Params: Dict[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
-    ) -> None:
+    ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_resource_policy(self, resourceArn: str) -> GetResourcePolicyOutputTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def import_source_credentials(
         self,
         token: str,
@@ -233,24 +234,21 @@ class CodeBuildClient(BaseClient):
         shouldOverwrite: bool = None,
     ) -> ImportSourceCredentialsOutputTypeDef:
         """
-        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
+        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def invalidate_project_cache(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
+        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_builds(
         self, sortOrder: Literal["ASCENDING", "DESCENDING"] = None, nextToken: str = None
     ) -> ListBuildsOutputTypeDef:
         """
-        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_builds)
+        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_builds)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_builds_for_project(
         self,
         projectName: str,
@@ -258,16 +256,14 @@ class CodeBuildClient(BaseClient):
         nextToken: str = None,
     ) -> ListBuildsForProjectOutputTypeDef:
         """
-        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
+        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_curated_environment_images(self) -> ListCuratedEnvironmentImagesOutputTypeDef:
         """
-        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
+        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_projects(
         self,
         sortBy: Literal["NAME", "CREATED_TIME", "LAST_MODIFIED_TIME"] = None,
@@ -275,10 +271,9 @@ class CodeBuildClient(BaseClient):
         nextToken: str = None,
     ) -> ListProjectsOutputTypeDef:
         """
-        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_projects)
+        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_projects)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_report_groups(
         self,
         sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
@@ -287,10 +282,9 @@ class CodeBuildClient(BaseClient):
         maxResults: int = None,
     ) -> ListReportGroupsOutputTypeDef:
         """
-        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
+        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_reports(
         self,
         sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
@@ -299,10 +293,9 @@ class CodeBuildClient(BaseClient):
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsOutputTypeDef:
         """
-        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_reports)
+        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_reports)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_reports_for_report_group(
         self,
         reportGroupArn: str,
@@ -312,10 +305,9 @@ class CodeBuildClient(BaseClient):
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
-        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
+        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_shared_projects(
         self,
         sortBy: Literal["ARN", "MODIFIED_TIME"] = None,
@@ -324,10 +316,9 @@ class CodeBuildClient(BaseClient):
         nextToken: str = None,
     ) -> ListSharedProjectsOutputTypeDef:
         """
-        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
+        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_shared_report_groups(
         self,
         sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
@@ -336,22 +327,19 @@ class CodeBuildClient(BaseClient):
         maxResults: int = None,
     ) -> ListSharedReportGroupsOutputTypeDef:
         """
-        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
+        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_source_credentials(self) -> ListSourceCredentialsOutputTypeDef:
         """
-        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
+        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def put_resource_policy(self, policy: str, resourceArn: str) -> PutResourcePolicyOutputTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def start_build(
         self,
         projectName: str,
@@ -393,22 +381,21 @@ class CodeBuildClient(BaseClient):
         privilegedModeOverride: bool = None,
         timeoutInMinutesOverride: int = None,
         queuedTimeoutInMinutesOverride: int = None,
+        encryptionKeyOverride: str = None,
         idempotencyToken: str = None,
         logsConfigOverride: LogsConfigTypeDef = None,
         registryCredentialOverride: RegistryCredentialTypeDef = None,
         imagePullCredentialsTypeOverride: Literal["CODEBUILD", "SERVICE_ROLE"] = None,
     ) -> StartBuildOutputTypeDef:
         """
-        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.start_build)
+        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.start_build)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def stop_build(self, id: str) -> StopBuildOutputTypeDef:
         """
-        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.stop_build)
+        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.stop_build)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def update_project(
         self,
         name: str,
@@ -429,20 +416,19 @@ class CodeBuildClient(BaseClient):
         vpcConfig: VpcConfigTypeDef = None,
         badgeEnabled: bool = None,
         logsConfig: LogsConfigTypeDef = None,
+        fileSystemLocations: List[ProjectFileSystemLocationTypeDef] = None,
     ) -> UpdateProjectOutputTypeDef:
         """
-        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.update_project)
+        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.update_project)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def update_report_group(
         self, arn: str, exportConfig: ReportExportConfigTypeDef = None
     ) -> UpdateReportGroupOutputTypeDef:
         """
-        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
+        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def update_webhook(
         self,
         projectName: str,
@@ -451,41 +437,25 @@ class CodeBuildClient(BaseClient):
         filterGroups: List[List[WebhookFilterTypeDef]] = None,
     ) -> UpdateWebhookOutputTypeDef:
         """
-        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
+        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
         """
 
     @overload
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-    def get_paginator(
-        self, operation_name: Literal["list_builds"]
-    ) -> paginator_scope.ListBuildsPaginator:
+    def get_paginator(self, operation_name: Literal["list_builds"]) -> ListBuildsPaginator:
         """
-        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
         """
 
     @overload
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_paginator(
         self, operation_name: Literal["list_builds_for_project"]
-    ) -> paginator_scope.ListBuildsForProjectPaginator:
+    ) -> ListBuildsForProjectPaginator:
         """
-        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
         """
 
     @overload
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-    def get_paginator(
-        self, operation_name: Literal["list_projects"]
-    ) -> paginator_scope.ListProjectsPaginator:
+    def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.40/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
         """
-
-
-class Exceptions:
-    AccountLimitExceededException: Boto3ClientError
-    ClientError: Boto3ClientError
-    InvalidInputException: Boto3ClientError
-    OAuthProviderException: Boto3ClientError
-    ResourceAlreadyExistsException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
